# YRAG is aimed to build up Machine Learning Application quickly!
This is a simple example package. You can use
[yrag](https://github.com/Yougigun/yrag)
to write your content.


## Package included: 
### Data Science package
- numpy            -      1.18.4
- pandas           -     1.0.3
- scipy            -      1.4.1
- scikit-learn     -      0.23.0
- tensorflow       -      2.2.0
- torch            -      1.4.0+cpu
- transformers     -      2.9.1

### Database package
- pymssql          -      2.1.4
- PyMySQL          -      0.9.3
- redis            -      3.5.2
- requests         -      2.23.0


## Note
- Build package : python setup.py sdist bdist_wheel
- Upload package : python -m twine upload dist/*   